package vario

/** Vario's data package.
 *
 * Supported tokenized datatypes for convenience purposes:
 *{{{
 * 'b // vario.data.Bool
 * 'x // vario.data.Byte
 * 'c // vario.data.Char
 * 'd // vario.data.Double
 * 'f // vario.data.Float
 * 'i // vario.data.Int
 * 'l // vario.data.Long
 * 's // vario.data.Short
 *}}}
 * Supported tokenized Joda types for convenience purposes:
 *{{{
 * 'M // vario.data.Month
 * 'D // vario.data.Date
 * 'U // vario.data.Minute
 * 'V // vario.data.Second
 * 'T // vario.data.Time
 * 'Z // vario.data.DateTime
 * 'P // vario.data.Timestamp
 *}}}
 * Supported tokenized variable types for convenience purposes:
 *{{{
 * 'Y // vario.data.Symbol
 * 'S // vario.data.String
 *}}}
 *
 * @author myst3r10n
 */
package object data {

  import Datatype.Datatype

  /** Convert a tokenized type
   *
   * @param token tokenized type
   *
   * @return resolved [[vario.data.Datatype]]
  */
  final def by(token: Symbol): Datatype =
    token match {

      case 'n => Datatype.None
      case 'b => Datatype.Bool
      case 'x => Datatype.Byte
      case 'c => Datatype.Char
      case 'd => Datatype.Double
      case 'f => Datatype.Float
      case 'i => Datatype.Int
      case 'l => Datatype.Long
      case 's => Datatype.Short

      case 'M => Datatype.Month
      case 'D => Datatype.Date
      case 'U => Datatype.Minute
      case 'V => Datatype.Second
      case 'T => Datatype.Time
      case 'Z => Datatype.DateTime
      case 'P => Datatype.Timestamp

      case 'Y => Datatype.Symbol
      case 'S => Datatype.String

    }

  /** Convert a series of tokenized types
   *
   * @param tokens tokenized types
   *
   * @return array of resolved [[vario.data.Datatype]]s
  */
  final def by(tokens: String): Array[Datatype] =
    for(token <- tokens.toCharArray)
      yield(by(Symbol(token.toString)))

  /** Size of each supported [[vario.data.Datatype]]s in bytes. */
  final def sizeOf = SizeOf

}

